@@ -1,21 +1,24 @@
 #' Print methods
 #'
 #' @param x An object of class `infer`, i.e. output from [specify()] or
-#'   [hypothesize()].
+#'   [hypothesize()], or of class `infer_layer`, i.e. output from
+#'   [shade_p_value()] or [shade_confidence_interval()].
 #' @param ... Arguments passed to methods.
 #' @importFrom glue glue_collapse
 #'
+#' @rdname print.infer
 #' @export
 print.infer <- function(x, ...) {
   attrs <- names(attributes(x))
   header <- character(3)
   if ("response" %in% attrs) {
     header[1] <- glue_null(
-      'Response: {attr(x, "response")} ({attr(x, "response_type")})'
+      'Response: {response_name(x)} ({attr(x, "response_type")})'
     )
     if ("explanatory" %in% attrs) {
       header[2] <- glue_null(
-        'Explanatory: {attr(x, "explanatory")} ({attr(x, "explanatory_type")})'
+        'Explanatory: {paste0(paste0(explanatory_name(x), " (", 
+        attr(x, "explanatory_type"), ")"), collapse = ", ")}'
       )
     }
   }
@@ -28,3 +31,15 @@ print.infer <- function(x, ...) {
 
   NextMethod()
 }
+
+#' @rdname print.infer
+#' @export
+print.infer_layer <- function(x, ...) {
+  cat(x)
+}
+
+#' @rdname print.infer
+#' @export
+print.infer_dist <- function(x, ...) {
+  cat(x)
+}
