@@ -46,6 +46,7 @@
 #' @importFrom rlang f_lhs
 #' @importFrom rlang f_rhs
 #' @importFrom stats as.formula
+#' @family wrapper functions
 #' @export
 t_test <- function(x, formula,
                    response = NULL,
@@ -56,6 +57,7 @@ t_test <- function(x, formula,
                    conf_int = TRUE,
                    conf_level = 0.95,
                    ...) {
+  
   check_conf_level(conf_level)
 
   # convert all character and logical variables to be factor variables
@@ -70,23 +72,17 @@ t_test <- function(x, formula,
                        response = response, explanatory = explanatory)
 
   # match with old "dot" syntax in t.test
-  if (alternative %in% c("two-sided", "two_sided", "two sided")) {
+  if (alternative %in% c("two-sided", "two_sided", "two sided", "two.sided")) {
     alternative <- "two.sided"
   }
 
   # two sample
   if (has_explanatory(x)) {
-    # if (!is.null(order)) {
-    #   x[[as.character(attr(x, "explanatory"))]] <- factor(explanatory_variable(x),
-    #                                                       levels = c(order[1],
-    #                                                                  order[2]),
-    #                                                       ordered = TRUE)
-    # }
-    order <- check_order(x, explanatory_variable(x), order, in_calculate = FALSE)
+    order <- check_order(x, order, in_calculate = FALSE, stat = NULL)
     x <- reorder_explanatory(x, order)
-    prelim <- stats::t.test(formula = as.formula(paste0(attr(x, "response"),
+    prelim <- stats::t.test(formula = as.formula(paste0(response_name(x),
                                                         " ~ ",
-                                                        attr(x, "explanatory"))),
+                                                        explanatory_name(x))),
                             data = x,
                             alternative = alternative,
                             mu = mu,
@@ -105,12 +101,12 @@ t_test <- function(x, formula,
     results <- prelim %>%
       dplyr::select(
         statistic, t_df = parameter, p_value = p.value, alternative,
-        lower_ci = conf.low, upper_ci = conf.high
+        estimate, lower_ci = conf.low, upper_ci = conf.high
       )
   } else {
     results <- prelim %>%
       dplyr::select(
-        statistic, t_df = parameter, p_value = p.value, alternative
+        statistic, t_df = parameter, p_value = p.value, alternative, estimate
       )
   }
 
@@ -122,6 +118,7 @@ t_test <- function(x, formula,
 #' @description
 #'
 #' A shortcut wrapper function to get the observed test statistic for a t test.
+#' This function has been deprecated in favor of the more general [observe()].
 #'
 #' @param x A data frame that can be coerced into a [tibble][tibble::tibble].
 #' @param formula A formula with the response variable on the left and the
@@ -158,6 +155,8 @@ t_test <- function(x, formula,
 #'       order = c("degree", "no degree"),
 #'       alternative = "two-sided")
 #'
+#' @family wrapper functions
+#' @family functions for calculating observed statistics
 #' @export
 t_stat <- function(x, formula,
                    response = NULL,
@@ -168,6 +167,12 @@ t_stat <- function(x, formula,
                    conf_int = FALSE,
                    conf_level = 0.95,
                    ...) {
+  .Deprecated(
+    new = "observe",
+    msg = c("The t_stat() wrapper has been deprecated in favor of the more " ,
+            "general observe(). Please use that function instead.")
+  )
+  
   check_conf_level(conf_level)
 
   # convert all character and logical variables to be factor variables
@@ -182,23 +187,17 @@ t_stat <- function(x, formula,
                        response = response, explanatory = explanatory)
 
   # match with old "dot" syntax in t.test
-  if (alternative %in% c("two-sided", "two_sided", "two sided")) {
+  if (alternative %in% c("two-sided", "two_sided", "two sided", "two.sided")) {
     alternative <- "two.sided"
   }
 
   # two sample
   if (has_explanatory(x)) {
-    # if (!is.null(order)) {
-    #   x[[as.character(attr(x, "explanatory"))]] <- factor(explanatory_variable(x),
-    #                                                       levels = c(order[1],
-    #                                                                  order[2]),
-    #                                                       ordered = TRUE)
-    # }
-    order <- check_order(x, explanatory_variable(x), order, in_calculate = FALSE)
+    order <- check_order(x, order, in_calculate = FALSE, stat = NULL)
     x <- reorder_explanatory(x, order)
-    prelim <- stats::t.test(formula = as.formula(paste0(attr(x, "response"),
+    prelim <- stats::t.test(formula = as.formula(paste0(response_name(x),
                                                         " ~ ",
-                                                        attr(x, "explanatory"))),
+                                                        explanatory_name(x))),
                             data = x,
                             alternative = alternative,
                             mu = mu,
@@ -254,6 +253,7 @@ t_stat <- function(x, formula,
 #'                  "far above average" = 1/6,
 #'                  "DK" = 1/6))
 #'
+#' @family wrapper functions
 #' @export
 chisq_test <- function(x, formula, response = NULL,
                        explanatory = NULL, ...) {
@@ -265,22 +265,20 @@ chisq_test <- function(x, formula, response = NULL,
 
   if (!(class(response_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
-      'The response variable of `{attr(x, "response")}` is not appropriate\n',
+      'The response variable of `{response_name(x)}` is not appropriate ',
       "since the response variable is expected to be categorical."
     )
   }
   if (has_explanatory(x) &&
       !(class(explanatory_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
-      'The explanatory variable of `{attr(x, "explanatory")}` is not appropriate\n',
+      'The explanatory variable of `{explanatory_name(x)}` is not appropriate ',
       "since the explanatory variable is expected to be categorical."
     )
   }
 
   x <- x %>%
-    select(one_of(c(
-      as.character((attr(x, "response"))), as.character(attr(x, "explanatory"))
-    ))) %>%
+    select(any_of(c(response_name(x), explanatory_name(x)))) %>%
     mutate_if(is.character, as.factor) %>%
     mutate_if(is.logical, as.factor)
 
@@ -295,7 +293,8 @@ chisq_test <- function(x, formula, response = NULL,
 #'
 #' A shortcut wrapper function to get the observed test statistic for a chisq
 #' test. Uses [chisq.test()][stats::chisq.test()], which applies a continuity
-#' correction.
+#' correction. This function has been deprecated in favor of the more 
+#' general [observe()].
 #'
 #' @param x A data frame that can be coerced into a [tibble][tibble::tibble].
 #' @param formula A formula with the response variable on the left and the
@@ -324,9 +323,17 @@ chisq_test <- function(x, formula, response = NULL,
 #'                  "far above average" = 1/6,
 #'                  "DK" = 1/6))
 #'
+#' @family wrapper functions
+#' @family functions for calculating observed statistics
 #' @export
 chisq_stat <- function(x, formula, response = NULL,
                        explanatory = NULL, ...) {
+  .Deprecated(
+    new = "observe",
+    msg = c("The chisq_stat() wrapper has been deprecated in favor of the ", 
+            "more general observe(). Please use that function instead.")
+  )
+  
   # Parse response and explanatory variables
   response    <- enquo(response)
   explanatory <- enquo(explanatory)
@@ -335,22 +342,20 @@ chisq_stat <- function(x, formula, response = NULL,
 
   if (!(class(response_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
-      'The response variable of `{attr(x, "response")}` is not appropriate\n',
+      'The response variable of `{response_name(x)}` is not appropriate ',
       "since the response variable is expected to be categorical."
     )
   }
   if (has_explanatory(x) &&
       !(class(explanatory_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
-      'The explanatory variable of `{attr(x, "explanatory")}` is not appropriate\n',
+      'The explanatory variable of `{explanatory_name(x)}` is not appropriate ',
       "since the response variable is expected to be categorical."
     )
   }
 
   x <- x %>%
-    select(one_of(c(
-      as.character((attr(x, "response"))), as.character(attr(x, "explanatory"))
-    ))) %>%
+    select(any_of(c(response_name(x), explanatory_name(x)))) %>%
     mutate_if(is.character, as.factor) %>%
     mutate_if(is.logical, as.factor)
 
@@ -438,6 +443,7 @@ check_conf_level <- function(conf_level) {
 #'           p = .2,
 #'           z = TRUE)
 #'
+#' @family wrapper functions
 #' @export
 prop_test <- function(x, formula,
                       response = NULL,
@@ -460,19 +466,19 @@ prop_test <- function(x, formula,
 
   if (!(class(response_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
-      'The response variable of `{attr(x, "response")}` is not appropriate\n',
+      'The response variable of `{response_name(x)}` is not appropriate\n',
       "since the response variable is expected to be categorical."
     )
   }
   if (has_explanatory(x) &&
       !(class(explanatory_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
-      'The explanatory variable of `{attr(x, "explanatory")}` is not appropriate\n',
+      'The explanatory variable of `{explanatory_name(x)}` is not appropriate ',
       "since the explanatory variable is expected to be categorical."
     )
   }
   # match with old "dot" syntax in t.test
-  if (alternative %in% c("two-sided", "two_sided", "two sided")) {
+  if (alternative %in% c("two-sided", "two_sided", "two sided", "two.sided")) {
     alternative <- "two.sided"
   }
 
@@ -483,7 +489,7 @@ prop_test <- function(x, formula,
     check_type(success, rlang::is_string)
 
     if (!(success %in% lvls)) {
-      stop_glue('{success} is not a valid level of {attr(x, "response")}.')
+      stop_glue('{success} is not a valid level of {response_name(x)}.')
     }
 
     lvls <- c(success, lvls[lvls != success])
@@ -494,12 +500,11 @@ prop_test <- function(x, formula,
   # two sample
   if (has_explanatory(x)) {
 
-    order <- check_order(x, explanatory_variable(x), order, in_calculate = FALSE)
+    order <- check_order(x, order, in_calculate = FALSE, stat = NULL)
 
     # make a summary table to supply to prop.test
     sum_table <- x %>%
-      select(as.character((attr(x, "response"))),
-             as.character(attr(x, "explanatory"))) %>%
+      select(response_name(x), explanatory_name(x)) %>%
       mutate_if(is.character, as.factor) %>%
       mutate_if(is.logical, as.factor) %>%
       table()
@@ -569,9 +574,9 @@ prop_test <- function(x, formula,
 }
 
 calculate_z <- function(x, results, success, p, order) {
-  exp <- if (has_explanatory(x)) {attr(x, "explanatory")} else {"NULL"}
+  exp <- if (has_explanatory(x)) {explanatory_name(x)} else {"NULL"}
   
-  form <- as.formula(paste0(attr(x, "response"), " ~ ", exp))
+  form <- as.formula(paste0(response_name(x), " ~ ", exp))
   
   stat <- x %>%
     specify(formula = form, success = success) %>%
